import { uniqueId } from "lodash-es";
import React, { useState } from "react";
import { getArrayLinks } from "./utilities/form";
import { DragItem } from "../templates";
import { ArrayAction } from "../templates/types";
import { classNames } from "@microsoft/fast-web-utilities";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import addItemStyle from "design-to-code/dist/stylesheets/web-components/style/common.add-item.css";
import cleanListStyle from "design-to-code/dist/stylesheets/web-components/style/common.clean-list.css";
import defaultFontStyle from "design-to-code/dist/stylesheets/web-components/style/common.default-font.css";
import invalidMessageStyle from "design-to-code/dist/stylesheets/web-components/style/common.invalid-message.css";
import removeItemStyle from "design-to-code/dist/stylesheets/web-components/style/common.remove-item.css";
import labelStyle from "design-to-code/dist/stylesheets/web-components/style/common.label.css";
import labelRegionStyle from "design-to-code/dist/stylesheets/web-components/style/common.label-region.css";
import ellipsisStyle from "design-to-code/dist/stylesheets/web-components/style/common.ellipsis.css";
import style from "./control.array.style.css";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
// tree-shaking
cssVariables;
addItemStyle;
cleanListStyle;
defaultFontStyle;
invalidMessageStyle;
removeItemStyle;
labelStyle;
labelRegionStyle;
ellipsisStyle;
style;
export const displayTextDataLocationKey = "dtc:form:control:array:display-text";
/**
 * Form control definition
 */
function ArrayControl(props) {
    const [data, setData] = useState(props.value);
    const [dragging, setDragging] = useState(false);
    /**
     * Render a button for adding an item to the array
     */
    function renderAddArrayItemTrigger() {
        return (React.createElement("button", { className: `dtc-array-control_add-item-button ${dtcClassName.commonAddItem}`, "aria-label": props.strings.arrayAddItemTip, onClick: arrayItemClickHandlerFactory(ArrayAction.add) }));
    }
    /**
     * Render an add array item section
     */
    function renderAddArrayItem() {
        const existingItemLength = Array.isArray(props.value)
            ? props.value.length
            : 0;
        if (props.maxItems > existingItemLength) {
            return (React.createElement("div", { className: `dtc-array-control_add-item ${dtcClassName.commonLabelRegion}` },
                React.createElement("div", { className: `dtc-array-control_add-item-label ${dtcClassName.commonLabel}` }, props.strings.arrayAddItemLabel),
                renderAddArrayItemTrigger()));
        }
    }
    /**
     * Renders an default array link item
     */
    function renderDefaultArrayLinkItem(value, index) {
        return (React.createElement("li", { className: "dtc-array-control_existing-item-list-item", key: `item-${index}`, id: uniqueId(index.toString()) },
            React.createElement("span", { className: classNames(`dtc-array-control_existing-item-list-item-link ${dtcClassName.commonDefaultFont} ${dtcClassName.commonEllipsis} dtc-array-control_existing-item-list-item-link__default`) }, value)));
    }
    /**
     * Renders default array items
     */
    function renderDefaultArrayLinkItems() {
        return getArrayLinks(props.default, props.schema[displayTextDataLocationKey]).map((value, index) => {
            return renderDefaultArrayLinkItem(value, index);
        });
    }
    /**
     * Renders the links to an array section to be activated
     */
    function renderExistingArrayItems() {
        const hasData = Array.isArray(props.value);
        const hasDefault = Array.isArray(props.default);
        if (hasData) {
            return (React.createElement("ul", { className: `dtc-array-control_existing-item-list ${dtcClassName.commonCleanList}` }, renderArrayLinkItems()));
        }
        if (hasDefault) {
            return (React.createElement("ul", { className: `dtc-array-control_existing-item-list ${dtcClassName.commonCleanList}` }, renderDefaultArrayLinkItems()));
        }
        return (React.createElement("ul", { className: `dtc-array-control_existing-item-list ${dtcClassName.commonCleanList}` }));
    }
    /**
     * Render UI for all items in an array
     */
    function renderArrayLinkItems() {
        const currentData = dragging ? data : props.value;
        return getArrayLinks(currentData, props.schema[displayTextDataLocationKey]).map((text, index) => {
            const invalidError = renderValidationError(index);
            return (React.createElement(React.Fragment, { key: props.dataLocation + index },
                React.createElement(DragItem, { key: index, index: index, minItems: props.minItems, itemLength: getArrayLinks(currentData, props.schema[displayTextDataLocationKey]).length, itemRemoveClassName: `dtc-array-control_existing-item-remove-button ${dtcClassName.commonRemoveItem}`, itemClassName: classNames("dtc-array-control_existing-item-list-item", [
                        "dtc-array-control_existing-itemListItem__invalid",
                        invalidError !== null,
                    ]), itemLinkClassName: "dtc-array-control_existing-item-list-item-link", removeDragItem: arrayItemClickHandlerFactory, onClick: arrayClickHandlerFactory, moveDragItem: handleMoveDragItem, dropDragItem: handleDropDragItem, dragStart: handleDragStart, dragEnd: handleDragEnd, strings: props.strings }, text),
                !!props.displayValidationInline ? invalidError : null));
        });
    }
    function renderValidationError(index) {
        if (typeof props.validationErrors === "undefined") {
            return null;
        }
        for (const error of props.validationErrors) {
            if (error.dataLocation.startsWith(`${props.dataLocation}.${index}`)) {
                return (React.createElement("div", { className: `dtc-array-control_invalid-message ${dtcClassName.commonInvalidMessage}` }, error.invalidMessage));
            }
        }
        return null;
    }
    /**
     * Array add/remove item click handler factory
     */
    function arrayItemClickHandlerFactory(type, index) {
        return (e) => {
            e.preventDefault();
            type === ArrayAction.add
                ? handleAddArrayItem()
                : handleRemoveArrayItem(index);
        };
    }
    /**
     * Array section link click handler factory
     */
    function arrayClickHandlerFactory(index) {
        return (e) => {
            e.preventDefault();
            props.onUpdateSection(props.dictionaryId, props.navigation[props.navigationConfigId].items[index]);
        };
    }
    /**
     * Handles adding an array item
     */
    function handleAddArrayItem() {
        if (typeof props.value === "undefined") {
            props.onChange({ value: [props.onAddExampleData("items")] });
        }
        else {
            props.onChange({
                value: props.onAddExampleData("items"),
                isArray: true,
            });
        }
    }
    /**
     * Handles removing an array item
     */
    function handleRemoveArrayItem(index) {
        props.onChange({ value: void 0, isArray: true, index });
    }
    /**
     * Handle the start of the drag action
     */
    function handleDragStart(config) {
        setDragging(true);
        setData([].concat(props.value || []));
        return config;
    }
    /**
     * Handle the end of the drag action
     */
    function handleDragEnd() {
        setDragging(false);
    }
    /**
     * Handle moving the drag item
     */
    function handleMoveDragItem(sourceIndex, targetIndex) {
        const currentData = [].concat(props.value);
        if (sourceIndex !== targetIndex) {
            currentData.splice(targetIndex, 0, currentData.splice(sourceIndex, 1)[0]);
        }
        setData(currentData);
    }
    /**
     * Handle dropping the drag item
     * Triggers the onChange
     */
    function handleDropDragItem() {
        props.onChange({ value: data });
    }
    return (React.createElement("div", { className: classNames("dtc-array-control", ["dtc-array-control__disabled", props.disabled], ["dtc-array-control__invalid", props.invalidMessage !== ""]) },
        renderAddArrayItem(),
        renderExistingArrayItems()));
}
export { ArrayControl };
export default ArrayControl;
