import React from "react";
import { classNames } from "@microsoft/fast-web-utilities";
import { isDefault } from "./utilities/form";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import selectSpanStyle from "design-to-code/dist/stylesheets/web-components/style/common.select-span.css";
import defaultFontStyle from "design-to-code/dist/stylesheets/web-components/style/common.default-font.css";
import selectInputStyle from "design-to-code/dist/stylesheets/web-components/style/common.select-input.css";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
import style from "./control.select.style.css";
// tree-shaking
cssVariables;
selectSpanStyle;
defaultFontStyle;
selectInputStyle;
style;
/**
 * Form control definition
 */
function SelectControl(props) {
    function handleChange() {
        return (e) => {
            const value = props.options.find((option) => {
                return typeof option === "string"
                    ? option === e.target.value
                    : JSON.stringify(option) === e.target.value;
            });
            props.onChange({ value });
        };
    }
    /**
     * Stringify the select value
     */
    function stringify(value) {
        try {
            return JSON.stringify(value);
        }
        catch (e) {
            return value;
        }
    }
    function getValue() {
        return typeof props.value !== "undefined"
            ? props.value
            : typeof props.default !== "undefined"
                ? props.default
                : "";
    }
    /**
     * Renders the selects option elements
     */
    function renderOptions() {
        return (props.options || []).map((item, index) => {
            return (React.createElement("option", { key: index, value: item }, typeof item === "string" || typeof item === "number"
                ? item
                : stringify(item)));
        });
    }
    return (React.createElement("span", { className: classNames(`dtc-select-control ${dtcClassName.commonSelectSpan}`, ["dtc-select-control__disabled", props.disabled], [
            `dtc-select-control__default ${dtcClassName.commonDefaultFont}`,
            isDefault(props.value, props.default),
        ]) },
        React.createElement("select", { className: `dtc-select-control_input ${dtcClassName.commonSelectInput}`, onChange: handleChange(), value: getValue(), disabled: props.disabled, ref: props.elementRef, onBlur: props.updateValidity, onFocus: props.reportValidity }, renderOptions())));
}
export { SelectControl };
export default SelectControl;
