import React from "react";
import { classNames } from "@microsoft/fast-web-utilities";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import themeStyle from "./control.theme.style.css";
// tree-shaking
cssVariables;
themeStyle;
var Theme;
(function (Theme) {
    Theme["Light"] = "light";
    Theme["Dark"] = "dark";
})(Theme || (Theme = {}));
/**
 * Custom form control definition
 */
function ThemeControl(props) {
    function onChange(value) {
        props.onChange({ value });
    }
    function isChecked(theme) {
        return (props.value === theme ||
            (typeof props.value === "undefined" && props.default === theme));
    }
    function getInputClassName(theme) {
        return theme === Theme.Dark
            ? "dtc-theme-control_input__dark"
            : "dtc-theme-control_input__light";
    }
    function getThemeLabel(theme) {
        switch (theme) {
            case Theme.Dark:
                return props.strings.themeDarkLabel;
            case Theme.Light:
                return props.strings.themeLightLabel;
        }
    }
    function renderInput(theme) {
        if (props.options && Array.isArray(props.options)) {
            const option = props.options.find((item) => {
                return item === theme;
            });
            if (typeof option !== "undefined") {
                return (React.createElement("input", { className: classNames("dtc-theme-control_input", getInputClassName(theme)), id: props.dataLocation, type: "radio", value: theme, name: props.dataLocation, "aria-label": getThemeLabel(theme), onChange: onChange.bind(this, theme), checked: isChecked(theme), disabled: props.disabled }));
            }
        }
    }
    return (React.createElement("div", { className: classNames("dtc-theme-control", [
            "dtc-theme-control__disabled",
            props.disabled,
        ]) },
        renderInput(Theme.Light),
        renderInput(Theme.Dark)));
}
export { ThemeControl };
export default ThemeControl;
