import React from "react";
import { ControlConfig, FormHTMLElement, ControlTemplateUtilitiesProps } from "./template.control.utilities.props";
import { BadgeType, ControlType, OnChangeConfig } from "./types";
import { FormStrings } from "../form.props";
/**
 * Custom templates can make use of the available utility functions
 */
export interface RenderSoftRemoveProps {
    className: string;
    required: boolean;
    softRemove?: boolean;
    type: ControlType;
    disabled?: boolean;
    data: boolean;
    cache: string;
    dataLocation: string;
    dictionaryId: string;
    setCache: (cache: any) => void;
    onChange: (config: OnChangeConfig) => void;
}
export declare function renderSoftRemove(props: RenderSoftRemoveProps): JSX.Element;
export interface RenderBadgeProps {
    className: string;
    badge?: BadgeType;
    badgeDescription?: string;
}
export declare function renderBadge(props: RenderBadgeProps): React.ReactNode;
export interface RenderConstValueIndicatorProps {
    const?: boolean;
    data: any;
    className: string;
    disabled?: boolean;
    strings: FormStrings;
    dataLocation: string;
    dictionaryId: string;
    onChange: (config: OnChangeConfig) => void;
}
export declare function renderConstValueIndicator(props: RenderConstValueIndicatorProps): React.ReactNode;
export interface RenderDefaultValueIndicatorProps {
    default?: any;
    data: any;
    className: string;
    disabled?: boolean;
    strings: FormStrings;
    dataLocation: string;
    dictionaryId: string;
    onChange: (config: OnChangeConfig) => void;
}
/**
 * Renders an indicator that signifies that the value
 * displayed is a default value
 */
export declare function renderDefaultValueIndicator(props: RenderDefaultValueIndicatorProps): React.ReactNode;
export interface HandleChangeProps {
    onChange: (config: OnChangeConfig) => void;
    dataLocation: string;
    dictionaryId: string;
}
export declare function handleChange(props: HandleChangeProps): (config: OnChangeConfig) => void;
export interface HandleSetDefaultValueProps {
    onChange: (config: OnChangeConfig) => void;
    dataLocation: string;
    dictionaryId: string;
    default?: any;
}
export declare function handleSetDefaultValue(props: HandleSetDefaultValueProps): () => void;
export interface HandleSetConstValueProps {
    onChange: (config: OnChangeConfig) => void;
    dataLocation: string;
    dictionaryId: string;
    const?: any;
}
export declare function handleSetConstValue(props: HandleSetConstValueProps): () => void;
export interface HandleSoftRemoveProps {
    onChange: (config: OnChangeConfig) => void;
    dataLocation: string;
    dictionaryId: string;
    data: any;
    cache: any;
    setCache: (cache: any) => void;
}
export interface RenderInvalidMessageProps {
    className: string;
    invalidMessage: string;
    displayValidationInline?: boolean;
}
/**
 * Renders an invalid message
 */
export declare function renderInvalidMessage(props: RenderInvalidMessageProps): React.ReactNode;
export interface RenderRequiredProps {
    required: boolean;
    className: string;
}
/**
 * Renders an indicator that a field is required
 */
export declare function renderRequired(props: RenderRequiredProps): React.ReactNode;
export interface UpdateValidityProps {
    ref: React.MutableRefObject<FormHTMLElement>;
    invalidMessage: string;
}
/**
 * updates the validity
 *
 * Use:
 * useEffect(() => {
 *    updateValidity();
 * });
 */
export declare function updateValidity(props: UpdateValidityProps): () => void;
export interface ReportValidityProps {
    ref: React.MutableRefObject<FormHTMLElement>;
    invalidMessage: string;
    displayValidationBrowserDefault?: boolean;
}
export interface GetConfigProps extends ControlTemplateUtilitiesProps {
    /**
     * The cache for soft removing data
     */
    cache: string;
    /**
     * The callback for updating the cache
     */
    setCache: (cache: string) => void;
    /**
     * The form element React ref
     */
    ref: React.MutableRefObject<null>;
}
export declare function getConfig(props: GetConfigProps): ControlConfig;
export interface HandleUpdateValueToDefaultValueProps {
    onChange: (config: OnChangeConfig) => void;
    dataLocation: string;
    dictionaryId: string;
    default: any;
}
/**
 * Explicitly updates the default value as the value
 */
export declare function handleUpdateValueToDefaultValue(props: HandleUpdateValueToDefaultValueProps): () => void;
